@@ -1,4 +1,4 @@
-# 2022.4.1,  pip install -U torch transformers func_timeout
+# 2022.4.7,  pip install -U torch transformers func_timeout
 import json,os,time, sys,math, torch,re
 from transformers import pipeline
 
@@ -9,7 +9,7 @@ model		= os.getenv("model","/grammar_error_correcter_v1")  #prithivida/grammar_e
 token_split	= lambda sent: re.findall(r"[\w']+|[.,!?;]", sent) # return list
 common_perc	= lambda snt="She has ready.", trans="She is ready.": ( toks := set(token_split(snt)), len([t for t in token_split(trans) if t in toks]) / (len(toks)+0.01) )[-1]
 
-def gecsnts(snts:list=["She has ready.","It are ok."],  max_length:int=128,  do_sample:bool=False, batch_size:int=32
+def s(snts:list=["She has ready.","It are ok."],  max_length:int=128,  do_sample:bool=False, batch_size:int=32
 		,unchanged_ratio:float=0.45, len_ratio:float=0.5, topk:int=0  # normally, set topk = batch_size 
 		, mget =lambda snts: [None for snt in snts] # cache_func , ie. r.mget
 		):
@@ -22,19 +22,23 @@ def gecsnts(snts:list=["She has ready.","It are ok."],  max_length:int=128,  do_
 		print(gecsnts.pipe("She has ready."), f"\t|cuda:{cuda}, task:{task}, model:{model}", flush=True )
 
 	gecs = mget(snts) 
-	newsnts = [snt for snt, gec in zip(snts, gecs) if gec is None]
+	newsnts = [snt for snt, gec in zip(snts, gecs) if gec is None and snt.count(' ') + 10 < max_length]
 	if topk > 0 and len(newsnts) > topk : newsnts = newsnts[0:topk] # only trans topk sents, added 2022.4.2
 
 	dic = {} #{'hello world': 'Hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello', 'I am ok.': 'I am ok.'}
-	for snt, tgt in zip(newsnts, gecsnts.pipe(newsnts,  max_length=max_length, do_sample=do_sample, batch_size=batch_size)):
-		trans = tgt['generated_text']  # todo : if token change > 50% , skip the trans
-		if not ' ' in trans or not ' ' in snt.strip(): # ' ' => "generated_text": "Then, a few years later, the saga began."
-			dic[snt] = snt # keep unchanged
-		elif common_perc(snt, trans) < unchanged_ratio or abs(math.log( len(snt)/len(trans))) > len_ratio:
-			dic[snt] = snt # changed too much, -> discard 
-		else:
-			dic[snt] = trans
-	return {snt:gec if gec is not None else dic.get(snt, snt) for snt, gec in zip(snts, gecs) } #return { snt: tgt['generated_text'] if ' ' in tgt['generated_text'] else snt for snt, tgt in zip(snts, pipe(snts, batch_size=batch_size) ) }
+	sntslen = len(snts) 
+	offset = 0 
+	while offset < sntslen: # added 2022.4.5
+		for snt, tgt in zip(snts, gecsnts.pipe(snts[offset:offset + batch_size],  max_length=max_length, do_sample=do_sample, batch_size=batch_size)):
+			trans = tgt['generated_text']  # todo : if token change > 50% , skip the trans
+			if not ' ' in trans or not ' ' in snt.strip(): # ' ' => "generated_text": "Then, a few years later, the saga began."
+				dic[snt] = snt # keep unchanged
+			elif common_perc(snt, trans) < unchanged_ratio or abs(math.log( len(snt)/len(trans))) > len_ratio:
+				dic[snt] = snt # changed too much, -> discard 
+			else:
+				dic[snt] = trans
+		offset = offset + batch_size
+	return {snt:gec if gec is not None else dic.get(snt, snt) for snt, gec in zip(snts, gecs) } 
 
 def gecsnts_timeout(snts:list=["She has ready.","It are ok."], timeout:int=6, max_length:int=128,  do_sample:bool=False, batch_size:int=32, unchanged_ratio:float=0.45, len_ratio:float=0.5):
 	''' '''
