@@ -4,9 +4,9 @@ import requests
 import pandas as pd
 import pyecharts.options as opts
 from pyecharts.charts import Bar
-from streamlit_echarts import st_pyecharts
+from streamlit_echarts import st_pyecharts,st_echarts
 
-import redis,spacy,json,requests
+import redis,spacy,json,requests,os
 from collections import defaultdict, Counter
 
 if not hasattr(spacy, 'nlp'): 
