@@ -19,6 +19,11 @@ def likelihood(a,b,c,d, minus=None):  #from: http://ucrel.lancs.ac.uk/llwizard.h
 		print ("likelihood ex:",e, a,b,c,d)
 		return 0
 
+def xblpop(r, name, arr, timeout=10, suc_prefix='suc:', err_prefix="err:"):
+	''' name:xsnt/xsnts, arr: {"snt": "hello"}  added 2022.4.4 '''
+	id  = r.xadd(name, arr)
+	return r.blpop([f"{suc_prefix}{id}",f"{err_prefix}{id}"], timeout=timeout)
+
 def getlog(logfile='daily.log'):
 	import logging
 	from logging.handlers import TimedRotatingFileHandler
